@@ -8,7 +8,7 @@ class QueryProtein:
 
     def __init__(self, username=None, password=None, server=None, authSource='admin',
                  database='datanator', max_entries=float('inf'), verbose=True, collection_str='protein',
-                 readPreference='primary'):
+                 readPreference='nearest'):
 
         self.mongo_manager = mongo_util.MongoUtil(MongoDB=server, username=username,
                                              password=password, authSource=authSource, db=database,
@@ -221,7 +221,7 @@ class QueryProtein:
 
     def get_info_by_taxonid_abundance(self, _id):
         '''
-            Get proteins whose name or kegg name contains string 'name'.
+            Get proteins associated with ncbi id.
 
             Args:
                 _id (:obj:`int`): ncbi taxonomy id.
